# コアモジュール

`wandas.core` モジュールは、Wandasライブラリの基盤となるコンポーネントを提供します。

## BaseFrame

BaseFrameはすべてのWandasフレームの基底クラスです。これは基本的なデータ構造と操作を定義します。

::: wandas.core.base_frame.BaseFrame

## ChannelMetadata

ChannelMetadataクラスはオーディオデータのチャンネルに関連するメタデータを管理します。

::: wandas.core.metadata.ChannelMetadata
